@@ -37,6 +37,9 @@ struct _GgvControlPrivate {
 	BonoboControl *zoom_control;
 
 	BonoboUIComponent *uic, *popup_uic;
+
+	/* GConfClient notification ID */
+	guint gconf_notify_id;
 };
 
 struct _GgvControlClassPrivate {
@@ -77,6 +80,13 @@ ggv_control_destroy (BonoboObject *object)
 
 	control = GGV_CONTROL (object);
 
+	if (control->priv->gconf_notify_id) {
+		gconf_client_notify_remove (gtk_gs_defaults_gconf_client (),
+									control->priv->gconf_notify_id);
+		control->priv->gconf_notify_id = 0;
+	}
+
+#if 0
 	if (control->priv->zoom_control) {
 		bonobo_object_unref(BONOBO_OBJECT(control->priv->zoom_control));
 		control->priv->zoom_control = NULL;
@@ -85,6 +95,7 @@ ggv_control_destroy (BonoboObject *object)
 		bonobo_object_unref(BONOBO_OBJECT(control->priv->uic));
 		control->priv->uic = NULL;
 	}
+#endif
 
 	if(BONOBO_OBJECT_CLASS (ggv_control_parent_class)->destroy)
 		BONOBO_OBJECT_CLASS (ggv_control_parent_class)->destroy (object);
@@ -109,6 +120,11 @@ static void
 sync_zoom_level_items(GgvControl *control)
 {
 	int i;
+	Bonobo_UIContainer container;
+
+	container = bonobo_ui_component_get_container (control->priv->uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
 
 	for(i = 0; zoom_level_items[i].path; i++) {
 		if(fabs(ggv_postscript_view_get_zoom_factor(control->priv->ps_view) - zoom_level_items[i].level) < 0.001) {
@@ -209,8 +225,6 @@ zoomable_zoom_to_fit_cb (BonoboZoomable *zoomable, GgvControl *control)
 	new_zoom_level =
 		ggv_postscript_view_zoom_to_fit (control->priv->ps_view, FALSE);
 
-	g_warning("zoom to fit: %f", new_zoom_level);
-
 	g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
 						   new_zoom_level);
 }
@@ -341,6 +355,8 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
 			}
 			break;
+		default:
+			break;
 		}
 		break;
 	case GDK_BackSpace:
@@ -366,6 +382,8 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) - 1);
 			}
 			break;
+		default:
+			break;
 		}
 		break;
 	case GDK_Left:
@@ -486,6 +504,11 @@ static void
 _set_zoom_items_sensitivity(GgvControl *control, BonoboUIComponent *uic, gboolean sens)
 {
 	gchar *prop_val = sens?"1":"0";
+	Bonobo_UIContainer container;
+
+	container = bonobo_ui_component_get_container (uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
 
 	bonobo_ui_component_set_prop(uic, "/commands/ZoomIn",
 								 "sensitive", prop_val, NULL);
@@ -672,7 +695,6 @@ ggv_control_class_init (GgvControlClass *klass)
 	GObjectClass *object_class = (GObjectClass *)klass;
 	BonoboObjectClass *bonobo_object_class = (BonoboObjectClass *)klass;
 	BonoboControlClass *control_class = (BonoboControlClass *)klass;
-	int i;
 
 	ggv_control_parent_class = gtk_type_class (bonobo_control_get_type ());
 
@@ -701,7 +723,7 @@ ps_view_property_changed_handler(BonoboListener    *listener,
 {
         GgvControl *control = GGV_CONTROL(data);
 
-        if(!g_strcasecmp(event_name, "Bonobo/Property:change:page")) {
+        if(!g_ascii_strcasecmp(event_name, "Bonobo/Property:change:page")) {
 			set_zoom_items_sensitivity(control, BONOBO_ARG_GET_INT(any) != -1);
         }
 }
@@ -709,7 +731,6 @@ ps_view_property_changed_handler(BonoboListener    *listener,
 GgvControl *
 ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 {
-	BonoboControl         *retval;
 	BonoboPropertyBag     *property_bag;
 	BonoboPropertyControl *property_control;
 	GtkWidget *view;
@@ -734,8 +755,7 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 	g_signal_connect(G_OBJECT(view), "button_press_event",
 					 G_CALLBACK(ggv_control_button_press_event), control);
 
-	control->priv->root = gtk_scrolled_window_new(ggv_postscript_view_get_hadj(ps_view),
-												  ggv_postscript_view_get_vadj(ps_view));
+	control->priv->root = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(control->priv->root);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(control->priv->root),
 										GTK_SHADOW_IN);
@@ -828,12 +848,11 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 	control->priv->pane_auto_jump = gconf_client_get_bool(gtk_gs_defaults_gconf_client(),
 														  "/apps/ggv/control/autojump",
 														  NULL);
-	gconf_client_notify_add(gtk_gs_defaults_gconf_client(),
-							"/apps/ggv/control",
-							(GConfClientNotifyFunc)ggv_control_prefs_changed,
-							control, NULL, NULL);
-
-	set_zoom_items_sensitivity(control, FALSE);
+	control->priv->gconf_notify_id =
+		gconf_client_notify_add(gtk_gs_defaults_gconf_client(),
+								"/apps/ggv/control",
+								(GConfClientNotifyFunc)ggv_control_prefs_changed,
+								control, NULL, NULL);
 
 	return control;
 }
