@@ -33,7 +33,6 @@
 
 struct _GgvPostScriptViewPrivate {
 	GtkWidget *gs;
-	GtkObject *hadj, *vadj;
 
 	GNOME_GGV_Size def_size;
 	GNOME_GGV_Orientation def_orientation;
@@ -42,6 +41,7 @@ struct _GgvPostScriptViewPrivate {
 	gboolean pan;
 	gdouble prev_x, prev_y;
 	gchar *tmp_name;
+	guint gconf_notify_id;
 
 	GgvMsgWindow *msg_win;
 	GgvSidebar *sidebar;
@@ -118,7 +118,6 @@ static const gchar *size_paths[] = {
 void
 get_status(GgvPostScriptView *ps_view, BonoboArg *arg)
 {
-	GtkGS *gs = GTK_GS(ps_view->priv->gs);
 	gchar *status;
 
 	g_assert(arg->_type == TC_CORBA_string);
@@ -150,6 +149,11 @@ static void
 set_file_items_sensitivity(GgvPostScriptView *ps_view, gboolean sens)
 {
 	gchar *prop_val = sens?"1":"0";
+	Bonobo_UIContainer container;
+
+	container = bonobo_ui_component_get_container (ps_view->priv->uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
 
 	bonobo_ui_component_set_prop(ps_view->priv->uic, "/commands/FileSaveMarked",
 								 "sensitive", prop_val, NULL);
@@ -164,6 +168,11 @@ _set_page_items_sensitivity(GgvPostScriptView *ps_view, BonoboUIComponent *uic)
 {
 	GtkGS *gs = GTK_GS(ps_view->priv->gs);
 	gchar *prop_val;
+	Bonobo_UIContainer container;
+
+	container = bonobo_ui_component_get_container (uic);
+	if (container == CORBA_OBJECT_NIL)
+		return;
 
 	prop_val = (gtk_gs_get_current_page(gs) >= gtk_gs_get_page_count(gs) - 1 ||
 				gtk_gs_get_current_page(gs) < 0)?
@@ -457,7 +466,6 @@ load_ps_from_file (BonoboPersistFile *pf, const CORBA_char *filename,
 				   CORBA_Environment *ev, void *data)
 {
 	GgvPostScriptView *ps_view;
-	BonoboArg *arg;
 
 	g_return_val_if_fail (data != NULL, -1);
 	g_return_val_if_fail (GGV_IS_POSTSCRIPT_VIEW (data), -1);
@@ -960,8 +968,6 @@ BonoboUIVerb ggv_postscript_view_verbs[] = {
 static void
 ggv_postscript_view_create_ui(GgvPostScriptView *ps_view)
 {
-	BonoboUINode *ui_root;
-	GgvPostScriptViewClass *klass = GGV_POSTSCRIPT_VIEW_CLASS(G_OBJECT_GET_CLASS(ps_view));
 	gint i;
 
 	g_return_if_fail(ps_view != NULL);
@@ -1120,10 +1126,13 @@ ggv_postscript_view_get_prop(BonoboPropertyBag *bag,
         case GTK_GS_ORIENTATION_SEASCAPE:
 			w = gs->ury - gs->lly;
 			break;
+		default:
+			w = 0;
+			break;
 		}
 		w = MAX(w, 0);
 		*(CORBA_long *)arg->_value = w;
-		break;
+		break;		
 	}
 	case PROP_HEIGHT: {
 		CORBA_float h;
@@ -1142,6 +1151,8 @@ ggv_postscript_view_get_prop(BonoboPropertyBag *bag,
         case GTK_GS_ORIENTATION_SEASCAPE:
 			h = gs->urx - gs->llx;
 			break;
+		default:
+			h = 0;
 		}
 		h = MAX(h, 0);
 		*(CORBA_long *)arg->_value = h;
@@ -1403,11 +1414,11 @@ ggv_postscript_view_add_interfaces (GgvPostScriptView *ps_view,
 	/* BonoboItemContainer */
 	item_container = bonobo_item_container_new ();
 
-	gtk_signal_connect (GTK_OBJECT (item_container),
-						"get_object",
-						GTK_SIGNAL_FUNC (ggv_postscript_view_get_object),
-						ps_view);
-
+	g_signal_connect (G_OBJECT (item_container),
+					  "get_object",
+					  G_CALLBACK (ggv_postscript_view_get_object),
+					  ps_view);
+	
 	bonobo_object_add_interface (BONOBO_OBJECT (to_aggregate),
 								 BONOBO_OBJECT (item_container));
 
@@ -1556,6 +1567,11 @@ ggv_postscript_view_destroy(BonoboObject *object)
 
 	ps_view = GGV_POSTSCRIPT_VIEW(object);
 
+	if (ps_view->priv->gconf_notify_id) {
+		gconf_client_notify_remove (gtk_gs_defaults_gconf_client (),
+									ps_view->priv->gconf_notify_id);
+		ps_view->priv->gconf_notify_id = 0;
+	}
 	if(ps_view->priv->property_bag) {
 		bonobo_object_unref(BONOBO_OBJECT(ps_view->priv->property_bag));
 		ps_view->priv->property_bag = NULL;
@@ -1637,6 +1653,16 @@ impl_GNOME_GGV_PostScriptView_getPages(PortableServer_Servant servant,
 	return retval;
 }
 
+static void
+impl_GNOME_GGV_PostScriptView_reload(PortableServer_Servant servant,
+									   CORBA_Environment *ev)
+{
+	GgvPostScriptView *ps_view;
+
+	ps_view = GGV_POSTSCRIPT_VIEW(bonobo_object_from_servant(servant));
+	gtk_gs_reload(GTK_GS(ps_view->priv->gs));
+}
+
 static void
 ggv_postscript_view_class_init(GgvPostScriptViewClass *klass)
 {
@@ -1655,6 +1681,7 @@ ggv_postscript_view_class_init(GgvPostScriptViewClass *klass)
 
 	epv->getDocument = impl_GNOME_GGV_PostScriptView_getDocument;
 	epv->getPages = impl_GNOME_GGV_PostScriptView_getPages;
+	epv->reload = impl_GNOME_GGV_PostScriptView_reload;
 
 	/* this seems as a nice place to load the prefs */
 	ggv_prefs_load();
@@ -1671,6 +1698,7 @@ BONOBO_TYPE_FUNC_FULL(GgvPostScriptView,
 					  BONOBO_TYPE_OBJECT,
 					  ggv_postscript_view);
 
+#if 0
 static void
 property_control_get_prop(BonoboPropertyBag *bag,
 						  BonoboArg         *arg,
@@ -1687,15 +1715,13 @@ property_control_get_prop(BonoboPropertyBag *bag,
 		g_assert_not_reached();
 	}
 }
+#endif
 
 static BonoboControl *
 property_control_get_cb(BonoboPropertyControl *property_control,
 						int page_number, void *closure)
 {
 	GgvPostScriptView *ps_view;
-	GtkWidget *container;
-	BonoboControl *control;
-	BonoboPropertyBag *property_bag;
 
 	g_return_val_if_fail(closure != NULL, NULL);
 	g_return_val_if_fail(GGV_IS_POSTSCRIPT_VIEW(closure), NULL);
@@ -1730,14 +1756,7 @@ property_control_get_cb(BonoboPropertyControl *property_control,
 static void
 document_changed_cb(GtkGS *gs, gpointer data)
 {
-	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(data);
-	gchar *fname;
-	gint page = gtk_gs_get_current_page(GTK_GS(ps_view->priv->gs));
-
-	fname = g_strdup(GTK_GS(ps_view->priv->gs)->gs_filename);
-	gtk_gs_load(GTK_GS(ps_view->priv->gs), fname);
-	ggv_postscript_view_goto_page(ps_view, page);
-	g_free(fname);				
+	gtk_gs_reload(gs);
 }
 
 static void
@@ -1771,6 +1790,53 @@ view_realized_cb(GtkGS *gs, gpointer data)
 	gdk_cursor_destroy(cursor);
 }
 
+static void
+ggv_postscript_view_prefs_changed(GConfClient *client, guint cnxn_id,
+								  GConfEntry *entry, gpointer user_data)
+{
+	GgvPostScriptView *ps_view = GGV_POSTSCRIPT_VIEW(user_data);
+	GtkGS *gs = GTK_GS(ps_view->priv->gs);
+
+	if(!strcmp(entry->key, "/apps/ggv/gtkgs/respect_eof")) 
+		gtk_gs_set_respect_eof(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/respect_eof", NULL));
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_orientation")) {
+		gtk_gs_set_override_orientation(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/override_orientation",
+																  NULL));
+		sync_orientation_items(ps_view);
+	}
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/orientation")) {
+		gtk_gs_set_default_orientation(gs, gconf_client_get_int(client, "/apps/ggv/gtkgs/orientation",
+																NULL));
+		sync_orientation_items(ps_view);
+	}
+#if 0
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/zoom")) {
+		gtk_gs_set_zoom(gs, gconf_client_get_float(client, "/apps/ggv/gtkgs/zoom",
+												   NULL));
+	}
+#endif
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/size")) {
+		gtk_gs_set_default_size(gs, gconf_client_get_int(client, "/apps/ggv/gtkgs/size",
+														 NULL));
+		sync_size_items(ps_view);
+	}
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/antialiasing"))
+		gtk_gs_set_antialiasing(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/antialiasing",
+														  NULL));
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/override_size")) {
+		gtk_gs_set_override_size(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/override_size",
+														   NULL));
+		sync_size_items(ps_view);
+	}
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/watch_doc"))
+		gtk_gs_set_watch_file(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/watch_doc",
+														NULL));
+	else if(!strcmp(entry->key, "/apps/ggv/gtkgs/show_scroll_rect"))
+		gtk_gs_set_show_scroll_rect(gs, gconf_client_get_bool(client, "/apps/ggv/gtkgs/show_scroll_rect",
+															  NULL));
+}
+
+
 GgvPostScriptView *
 ggv_postscript_view_construct(GgvPostScriptView *ps_view,
 							  GtkGS *gs, gboolean zoom_fit)
@@ -1782,9 +1848,17 @@ ggv_postscript_view_construct(GgvPostScriptView *ps_view,
 	g_return_val_if_fail(!GTK_WIDGET_REALIZED(gs), NULL);
 
 	/* Make sure GConf is initialized */
-	if(!gconf_is_initialized())
+	if(!gconf_is_initialized()) {
 		gconf_init(0, NULL, NULL);
-	
+	}
+
+	ps_view->priv->gconf_notify_id =
+		gconf_client_notify_add(gtk_gs_defaults_gconf_client(),
+								"/apps/ggv/gtkgs",
+								(GConfClientNotifyFunc)ggv_postscript_view_prefs_changed,
+								ps_view, NULL, NULL);
+															 
+
 	ps_view->priv->msg_win = ggv_msg_window_new(_("GhostScript output"));
 
 	ps_view->priv->gs = GTK_WIDGET(gs);
