@@ -27,20 +27,20 @@
 #  include <ggv-embeddable.h>
 #endif /* 0 */
 
-#define BONOBO_DEBUG
+#undef BONOBO_DEBUG
 
 #ifdef BONOBO_DEBUG
 #  include <signal.h>
 #  define LOG_FILE_NAME "/tmp/ggv-postscript-viewer.log"
 
 static FILE *log_file = NULL;
-static ggv_postscript_viewer_log_func(const gchar *log_domain,
-									  GLogLevelFlags log_level,
-									  const gchar *message,
-									  gpointer user_data)
+static void ggv_postscript_viewer_log_func(const gchar *log_domain,
+										   GLogLevelFlags log_level,
+										   const gchar *message,
+										   gpointer user_data)
 {
 	FILE *f = (FILE *)user_data;
-
+	
 	fprintf(f, "%s [%d]: %s\n", log_domain?log_domain:"", log_level, message);
 	fflush(f);
 }
