@@ -13,7 +13,7 @@ extern const gint ggv_max_orientation_labels;
 extern const gfloat ggv_unit_factors[];
 extern const gchar *ggv_unit_labels[];
 extern const gint ggv_max_unit_labels;
-extern const gfloat ggv_zoom_levels[];
+extern gfloat ggv_zoom_levels[];
 extern const gchar *ggv_zoom_level_names[];
 extern const gint ggv_max_zoom_levels;
 
@@ -45,4 +45,6 @@ void ggv_stock_init (void);
 
 void ggv_raise_and_focus_widget(GtkWidget *widget);
 
-#endif
+void ggv_get_window_size(GtkWidget *widget, gint *width, gint *height);
+
+#endif /* __GGV_UTILS_H__ */
